@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: Cabot.pm.in 148 2004-06-12 07:28:35Z weasel $
+# $Id: Cabot.pm.in 181 2005-02-28 21:05:00Z lfousse $
 
 # Copyright (c) 2001, 2003, 2004 Peter Palfrader
 #
@@ -34,10 +34,10 @@ BEGIN {
 	use Exporter ();
 	our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
-	$VERSION = '';
+	$VERSION = '0.0.20050504';
 	@ISA = qw(Exporter);
-	@EXPORT = qw(%CONFIG $VERSION &getkeydir &makekeydir &mkfds &readwritegpg &ask);
-	@EXPORT_OK = qw(%CONFIG $VERSION &getkeydir &makekeydir &mkfds &readwritegpg &ask);
+	@EXPORT = qw(%CONFIG $VERSION &initialize_cabot &getkeydir &makekeydir &mkfds &readwritegpg &ask);
+	@EXPORT_OK = qw(%CONFIG $VERSION &initialize_cabot &getkeydir &makekeydir &mkfds &readwritegpg &ask);
 	%EXPORT_TAGS = ( );
 	push @EXPORT_OK, '&genrandstring';
 	%EXPORT_TAGS = ( );
@@ -47,6 +47,22 @@ our @EXPORT_OK;
 
 our %CONFIG;
 
+sub initialize_cabot () {
+	my @rcfiles = ();
+	push @rcfiles, "/etc/cabot.conf";
+	push @rcfiles, ($ENV{'HOME'} . '/.cabotrc');
+	local $/ = undef;
+	foreach my $rcfile (@rcfiles) {
+		next unless -f $rcfile;
+		open CONFFILE, $rcfile;
+		my $rccontent = <CONFFILE>;
+		close CONFFILE;
+		unless (scalar eval $rccontent) {
+			die "Couldn't parse $rcfile: $@\n" if $@;
+		}
+	}
+}
+
 sub getkeydir($$;$) {
 	my ($what, $keyid, $uid) = @_;
 	$keyid =~ s/[^A-Za-z0-9 +_@<>()'.-]/_/g;
